@@ -14,17 +14,19 @@ from collections import OrderedDict
 from pprint import pprint
 
 # Error message from Kibana listing all possible saved objects types:
-# \"type\" must be one of [config, map, canvas-workpad, canvas-element, index-pattern, visualization, search, dashboard, url]
+# \"type\" must be one of [ alert, config, canvas-workpad, canvas-element, dashboard, index-pattern, map, query, search, url, visualization ]
 saved_objects_types = (
+    'alert',
     'config',
-    'map',
     'canvas-workpad',
     'canvas-element',
-    'index-pattern',
-    'visualization',
-    'search',
     'dashboard',
+    'index-pattern',
+    'map',
+    'query',
+    'search',
     'url',
+    'visualization'
 )
 
 
@@ -130,7 +132,7 @@ if __name__ == '__main__':
     args_parser.add_argument(
         '--backup-file-prefix',
         default='',
-        help='Backup file prefix for all spaces option: <prefix>-<space id>.ndjson',
+        help='Backup file prefix for all spaces option: <prefix><space id>.ndjson',
     )
     args = args_parser.parse_args()
 
